@@ -8,10 +8,5 @@ class mb_taxable_income(Variable):
     unit = CAD
     definition_period = YEAR
     reference = "https://www.revenue.pa.gov/FormsandPublications/FormsforIndividuals/PIT/Documents/2021/2021_pa-40in.pdf#page=8"
-
-    def formula(person, period, parameters):
-        province = person.household("province", period)
-        in_manitoba = province == province.possible_values.MANITOBA
-        return in_manitoba * add(
-            person, period, ["total_individual_pre_tax_income"]
-        )
+    defined_for = ProvinceCode.MB
+    adds = ["total_individual_pre_tax_income"]
