@@ -8,10 +8,5 @@ class nb_taxable_income(Variable):
     unit = CAD
     definition_period = YEAR
     reference = "https://www.revenue.pa.gov/FormsandPublications/FormsforIndividuals/PIT/Documents/2021/2021_pa-40in.pdf#page=8"
-
-    def formula(person, period, parameters):
-        province = person.household("province", period)
-        in_new_brunswick = province == province.possible_values.NEW_BRUNSWICK
-        return in_new_brunswick * add(
-            person, period, ["total_individual_pre_tax_income"]
-        )
+    defined_for = ProvinceCode.NB
+    adds = ["total_individual_pre_tax_income"]
